==> sight_21.1.1.orig.tar.gz: sight-21.1.1/modules/core/data/test/tu/SGetCameraTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2022 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::module::data
{

namespace ut
{

/**
 * @brief Test Etract Image series from Series Database
 */
class SGetCameraTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(SGetCameraTest);
CPPUNIT_TEST(extractsCameraFromCameraSeries);
CPPUNIT_TEST(extractsInvalidCameraSeries);
CPPUNIT_TEST(extractsValidExtrinsic);
CPPUNIT_TEST(extractsValidExtrinsic1);
CPPUNIT_TEST(extractsInvalidExtrinsic);
CPPUNIT_TEST(extractsCameraOutOfBoundIndex);
CPPUNIT_TEST(extractsExtrinsicOutOfBoundIndex);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp();
    void tearDown();

    void extractsCameraFromCameraSeries();
    void extractsInvalidCameraSeries();
    void extractsValidExtrinsic();
    void extractsValidExtrinsic1();
    void extractsCameraOutOfBoundIndex();
    void extractsExtrinsicOutOfBoundIndex();
    void extractsInvalidExtrinsic();
};

} //namespace ut

} //namespace sight::module::data

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/modules/core/data/test/tu/SGetCameraTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2022 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::module::data::ut
{

/**
 * @brief Test Etract Image series from Series Database
 */
class SGetCameraTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(SGetCameraTest);
CPPUNIT_TEST(extractsCameraFromCameraSet);
CPPUNIT_TEST(extractsInvalidCameraSet);
CPPUNIT_TEST(extractsValidExtrinsic);
CPPUNIT_TEST(extractsValidExtrinsic1);
CPPUNIT_TEST(extractsInvalidExtrinsic);
CPPUNIT_TEST(extractsCameraOutOfBoundIndex);
CPPUNIT_TEST(extractsExtrinsicOutOfBoundIndex);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void extractsCameraFromCameraSet();
    static void extractsInvalidCameraSet();
    static void extractsValidExtrinsic();
    static void extractsValidExtrinsic1();
    static void extractsCameraOutOfBoundIndex();
    static void extractsExtrinsicOutOfBoundIndex();
    static void extractsInvalidExtrinsic();
};

} // namespace sight::module::data::ut
